@@ -281,7 +281,7 @@ bool SearchEngine::search( const QString & words, const QString & method, int ma
       return false;
     }
 
-    QString txt = i18n("Search Results for '%1':", Qt::escape(words) );
+    QString txt = i18n("Search Results for '%1':", words.toHtmlEscaped() );
 
     mStderr = "<b>" + txt + "</b>\n";
 
@@ -465,6 +465,5 @@ bool SearchEngine::needsIndex( DocEntry *entry )
 
 }
 
-#include "searchengine.moc"
 
 // vim:ts=2:sw=2:et
